@@ -45,6 +45,7 @@
 #include "prefs_lokalize.h"
 #include "languagelistmodel.h"
 
+#include <kcoreaddons_version.h>
 #include <KToolBarPopupAction>
 #include <KActionCollection>
 #include <KStandardAction>
@@ -76,20 +77,7 @@ EditorTab::EditorTab(QWidget* parent, bool valid)
     , m_project(Project::instance())
     , m_catalog(new Catalog(this))
     , m_view(new EditorView(this, m_catalog/*,new keyEventHandler(this,m_catalog)*/))
-    , m_pologyProcessInProgress(false)
-    , m_sonnetDialog(nullptr)
-    , m_spellcheckStartUndoIndex(0)
-    , m_spellcheckStop(false)
-    , m_currentIsApproved(true)
-    , m_currentIsUntr(true)
-    , m_fullPathShown(false)
-    , m_doReplaceCalled(false)
-    , m_find(nullptr)
-    , m_replace(nullptr)
-    , m_syncView(nullptr)
-    , m_syncViewSecondary(nullptr)
     , m_valid(valid)
-    , m_dbusId(-1)
 {
     //QTime chrono;chrono.start();
 
@@ -105,7 +93,7 @@ EditorTab::EditorTab(QWidget* parent, bool valid)
     connect(SettingsController::instance(), &SettingsController::generalSettingsChanged, m_view, &EditorView::settingsChanged);
     connect(m_view->tabBar(), &QTabBar::currentChanged, this, &EditorTab::switchForm);
 
-    connect(m_view, QOverload<const DocPosition &>::of(&EditorView::gotoEntryRequested), this, QOverload<DocPosition>::of(&EditorTab::gotoEntry));
+    connect(m_view, qOverload<const DocPosition &>(&EditorView::gotoEntryRequested), this, qOverload<DocPosition>(&EditorTab::gotoEntry));
     connect(m_view, &EditorView::tmLookupRequested, this, &EditorTab::lookupSelectionInTranslationMemory);
 
     connect(this, &EditorTab::fileOpened, this, &EditorTab::indexWordsForCompletion, Qt::QueuedConnection);
@@ -204,8 +192,6 @@ void EditorTab::setupActions()
 
 
 //BEGIN dockwidgets
-    int i = 0;
-
     QVector<QAction*> altactions(ALTTRANS_SHORTCUTS);
     Qt::Key altlist[ALTTRANS_SHORTCUTS] = {
         Qt::Key_1,
@@ -219,7 +205,7 @@ void EditorTab::setupActions()
         Qt::Key_9
     };
     QAction* altaction;
-    for (i = 0; i < ALTTRANS_SHORTCUTS; ++i) {
+    for (int i = 0; i < ALTTRANS_SHORTCUTS; ++i) {
         altaction = tm->addAction(QStringLiteral("alttrans_insert_%1").arg(i));
         ac->setDefaultShortcut(altaction, QKeySequence(Qt::ALT + altlist[i]));
         altaction->setText(i18nc("@action:inmenu", "Insert alternate translation #%1", QString::number(i)));
@@ -229,38 +215,38 @@ void EditorTab::setupActions()
     m_altTransView = new AltTransView(this, m_catalog, altactions);
     addDockWidget(Qt::BottomDockWidgetArea, m_altTransView);
     ac->addAction(QStringLiteral("showmsgiddiff_action"), m_altTransView->toggleViewAction());
-    connect(this, QOverload<const DocPosition &>::of(&EditorTab::signalNewEntryDisplayed), m_altTransView, QOverload<const DocPosition &>::of(&AltTransView::slotNewEntryDisplayed));
+    connect(this, qOverload<const DocPosition &>(&EditorTab::signalNewEntryDisplayed), m_altTransView, qOverload<const DocPosition &>(&AltTransView::slotNewEntryDisplayed));
     connect(m_altTransView, &AltTransView::textInsertRequested, m_view, &EditorView::insertTerm);
-    connect(m_altTransView, &AltTransView::refreshRequested, m_view, QOverload<>::of(&EditorView::gotoEntry), Qt::QueuedConnection);
-    connect(m_catalog, QOverload<>::of(&Catalog::signalFileLoaded), m_altTransView, &AltTransView::fileLoaded);
+    connect(m_altTransView, &AltTransView::refreshRequested, m_view, qOverload<>(&EditorView::gotoEntry), Qt::QueuedConnection);
+    connect(m_catalog, qOverload<>(&Catalog::signalFileLoaded), m_altTransView, &AltTransView::fileLoaded);
 
     m_syncView = new MergeView(this, m_catalog, true);
     addDockWidget(Qt::BottomDockWidgetArea, m_syncView);
     sync1->addAction(QStringLiteral("showmergeview_action"), m_syncView->toggleViewAction());
-    connect(this, QOverload<const DocPosition &>::of(&EditorTab::signalNewEntryDisplayed), m_syncView, QOverload<const DocPosition &>::of(&MergeView::slotNewEntryDisplayed));
-    connect(m_catalog, QOverload<>::of(&Catalog::signalFileLoaded), m_syncView, &MergeView::cleanup);
-    connect(m_syncView, &MergeView::gotoEntry, this, QOverload<DocPosition, int>::of(&EditorTab::gotoEntry));
+    connect(this, qOverload<const DocPosition &>(&EditorTab::signalNewEntryDisplayed), m_syncView, qOverload<const DocPosition &>(&MergeView::slotNewEntryDisplayed));
+    connect(m_catalog, qOverload<>(&Catalog::signalFileLoaded), m_syncView, &MergeView::cleanup);
+    connect(m_syncView, &MergeView::gotoEntry, this, qOverload<DocPosition, int>(&EditorTab::gotoEntry));
 
     m_syncViewSecondary = new MergeView(this, m_catalog, false);
     addDockWidget(Qt::BottomDockWidgetArea, m_syncViewSecondary);
     sync2->addAction(QStringLiteral("showmergeviewsecondary_action"), m_syncViewSecondary->toggleViewAction());
-    connect(this, QOverload<const DocPosition &>::of(&EditorTab::signalNewEntryDisplayed), m_syncViewSecondary, QOverload<const DocPosition &>::of(&MergeView::slotNewEntryDisplayed));
-    connect(m_catalog, QOverload<>::of(&Catalog::signalFileLoaded), m_syncViewSecondary, &MergeView::cleanup);
-    connect(m_catalog, QOverload<const QString &>::of(&Catalog::signalFileLoaded), m_syncViewSecondary, QOverload<QString>::of(&MergeView::mergeOpen), Qt::QueuedConnection);
-    connect(m_syncViewSecondary, &MergeView::gotoEntry, this, QOverload<DocPosition, int>::of(&EditorTab::gotoEntry));
+    connect(this, qOverload<const DocPosition &>(&EditorTab::signalNewEntryDisplayed), m_syncViewSecondary, qOverload<const DocPosition &>(&MergeView::slotNewEntryDisplayed));
+    connect(m_catalog, qOverload<>(&Catalog::signalFileLoaded), m_syncViewSecondary, &MergeView::cleanup);
+    connect(m_catalog, qOverload<const QString &>(&Catalog::signalFileLoaded), m_syncViewSecondary, qOverload<QString>(&MergeView::mergeOpen), Qt::QueuedConnection);
+    connect(m_syncViewSecondary, &MergeView::gotoEntry, this, qOverload<DocPosition, int>(&EditorTab::gotoEntry));
 
     m_transUnitsView = new CatalogView(this, m_catalog);
     addDockWidget(Qt::LeftDockWidgetArea, m_transUnitsView);
     ac->addAction(QStringLiteral("showcatalogtreeview_action"), m_transUnitsView->toggleViewAction());
-    connect(this, QOverload<const DocPosition &>::of(&EditorTab::signalNewEntryDisplayed), m_transUnitsView, QOverload<const DocPosition &>::of(&CatalogView::slotNewEntryDisplayed));
-    connect(m_transUnitsView, &CatalogView::gotoEntry, this, QOverload<DocPosition, int>::of(&EditorTab::gotoEntry));
+    connect(this, qOverload<const DocPosition &>(&EditorTab::signalNewEntryDisplayed), m_transUnitsView, qOverload<const DocPosition &>(&CatalogView::slotNewEntryDisplayed));
+    connect(m_transUnitsView, &CatalogView::gotoEntry, this, qOverload<DocPosition, int>(&EditorTab::gotoEntry));
     connect(m_transUnitsView, &CatalogView::escaped, this, &EditorTab::setProperFocus);
     connect(m_syncView, &MergeView::mergeCatalogPointerChanged, m_transUnitsView, &CatalogView::setMergeCatalogPointer);
 
     m_notesView = new MsgCtxtView(this, m_catalog);
     addDockWidget(Qt::LeftDockWidgetArea, m_notesView);
     ac->addAction(QStringLiteral("showmsgctxt_action"), m_notesView->toggleViewAction());
-    connect(m_catalog, QOverload<>::of(&Catalog::signalFileLoaded), m_notesView, &MsgCtxtView::cleanup);
+    connect(m_catalog, qOverload<>(&Catalog::signalFileLoaded), m_notesView, &MsgCtxtView::cleanup);
     connect(m_notesView, &MsgCtxtView::srcFileOpenRequested, this, &EditorTab::dispatchSrcFileOpenRequest);
     connect(m_view, &EditorView::signalChanged, m_notesView, &MsgCtxtView::removeErrorNotes);
     connect(m_notesView, &MsgCtxtView::escaped, this, &EditorTab::setProperFocus);
@@ -273,7 +259,7 @@ void EditorTab::setupActions()
 
     QVector<QAction*> tmactions_insert(TM_SHORTCUTS);
     QVector<QAction*> tmactions_remove(TM_SHORTCUTS);
-    Qt::Key tmlist[TM_SHORTCUTS] = {
+    const Qt::Key tmlist[TM_SHORTCUTS] = {
         Qt::Key_1,
         Qt::Key_2,
         Qt::Key_3,
@@ -286,7 +272,7 @@ void EditorTab::setupActions()
         Qt::Key_0
     };
     QAction* tmaction;
-    for (i = 0; i < TM_SHORTCUTS; ++i) {
+    for (int i = 0; i < TM_SHORTCUTS; ++i) {
 //         action->setVisible(false);
         tmaction = tm->addAction(QStringLiteral("tmquery_insert_%1").arg(i));
         ac->setDefaultShortcut(tmaction, QKeySequence(Qt::CTRL + tmlist[i]));
@@ -307,16 +293,16 @@ void EditorTab::setupActions()
     TM::TMView* _tmView = new TM::TMView(this, m_catalog, tmactions_insert, tmactions_remove);
     addDockWidget(Qt::BottomDockWidgetArea, _tmView);
     tm->addAction(QStringLiteral("showtmqueryview_action"), _tmView->toggleViewAction());
-    connect(_tmView, &TM::TMView::refreshRequested, m_view, QOverload<>::of(&EditorView::gotoEntry), Qt::QueuedConnection);
+    connect(_tmView, &TM::TMView::refreshRequested, m_view, qOverload<>(&EditorView::gotoEntry), Qt::QueuedConnection);
     connect(_tmView, &TM::TMView::refreshRequested, this, &EditorTab::msgStrChanged, Qt::QueuedConnection);
     connect(_tmView, &TM::TMView::textInsertRequested, m_view, &EditorView::insertTerm);
     connect(_tmView, &TM::TMView::fileOpenRequested, this, &EditorTab::fileOpenRequested);
     connect(this, &EditorTab::fileAboutToBeClosed, m_catalog, &Catalog::flushUpdateDBBuffer);
     connect(this, &EditorTab::signalNewEntryDisplayed, m_catalog, &Catalog::flushUpdateDBBuffer);
-    connect(this, &EditorTab::signalNewEntryDisplayed, _tmView, QOverload<const DocPosition &>::of(&TM::TMView::slotNewEntryDisplayed)); //do this after flushUpdateDBBuffer
+    connect(this, &EditorTab::signalNewEntryDisplayed, _tmView, qOverload<const DocPosition &>(&TM::TMView::slotNewEntryDisplayed)); //do this after flushUpdateDBBuffer
 
     QVector<QAction*> gactions(GLOSSARY_SHORTCUTS);
-    Qt::Key glist[GLOSSARY_SHORTCUTS] = {
+    const Qt::Key glist[GLOSSARY_SHORTCUTS] = {
         Qt::Key_E,
         Qt::Key_H,
         //                         Qt::Key_G,
@@ -340,8 +326,7 @@ void EditorTab::setupActions()
         Qt::Key_Apostrophe
     };
     QAction* gaction;
-//     int i=0;
-    for (i = 0; i < GLOSSARY_SHORTCUTS; ++i) {
+    for (int i = 0; i < GLOSSARY_SHORTCUTS; ++i) {
 //         action->setVisible(false);
         gaction = glossary->addAction(QStringLiteral("glossary_insert_%1").arg(i));
         ac->setDefaultShortcut(gaction, QKeySequence(Qt::CTRL + glist[i]));
@@ -352,7 +337,7 @@ void EditorTab::setupActions()
     GlossaryNS::GlossaryView* _glossaryView = new GlossaryNS::GlossaryView(this, m_catalog, gactions);
     addDockWidget(Qt::BottomDockWidgetArea, _glossaryView);
     glossary->addAction(QStringLiteral("showglossaryview_action"), _glossaryView->toggleViewAction());
-    connect(this, &EditorTab::signalNewEntryDisplayed, _glossaryView, QOverload<DocPosition>::of(&GlossaryNS::GlossaryView::slotNewEntryDisplayed));
+    connect(this, &EditorTab::signalNewEntryDisplayed, _glossaryView, qOverload<DocPosition>(&GlossaryNS::GlossaryView::slotNewEntryDisplayed));
     connect(_glossaryView, &GlossaryNS::GlossaryView::termInsertRequested, m_view, &EditorView::insertTerm);
 
     gaction = glossary->addAction(QStringLiteral("glossary_define"), this, SLOT(defineNewTerm()));
@@ -460,14 +445,14 @@ void EditorTab::setupActions()
     connect(m_catalog, &Catalog::canRedoChanged, action, &QAction::setEnabled);
     action->setEnabled(false);
 
-    action = nav->addAction(KStandardAction::Find, this, SLOT(find()));
-    action = nav->addAction(KStandardAction::FindNext, this, SLOT(findNext()));
+    nav->addAction(KStandardAction::Find, this, SLOT(find()));
+    nav->addAction(KStandardAction::FindNext, this, SLOT(findNext()));
     action = nav->addAction(KStandardAction::FindPrev, this, SLOT(findPrev()));
     action->setText(i18nc("@action:inmenu", "Change searching direction"));
-    action = edit->addAction(KStandardAction::Replace, this, SLOT(replace()));
+    edit->addAction(KStandardAction::Replace, this, SLOT(replace()));
 
     connect(m_view, &EditorView::findRequested,     this, &EditorTab::find);
-    connect(m_view, &EditorView::findNextRequested, this, QOverload<>::of(&EditorTab::findNext));
+    connect(m_view, &EditorView::findNextRequested, this, qOverload<>(&EditorTab::findNext));
     connect(m_view, &EditorView::replaceRequested,  this, &EditorTab::replace);
 
 
@@ -520,7 +505,7 @@ void EditorTab::setupActions()
     connect(action, &QAction::triggered, (const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::source2target);
 
     ADD_ACTION_SHORTCUT("edit_unwrap-target", i18nc("@action:inmenu", "Unwrap target"), Qt::CTRL + Qt::Key_I)
-    connect(action, &QAction::triggered, m_view, QOverload<>::of(&EditorView::unwrap));
+    connect(action, &QAction::triggered, m_view, qOverload<>(&EditorView::unwrap));
 
     action = edit->addAction(QStringLiteral("edit_clear-target"), m_view->viewPort(), SLOT(removeTargetSubstring()));
     ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_D));
@@ -602,8 +587,8 @@ void EditorTab::setupActions()
     connect(this, &EditorTab::signalPriorFuzzyOrUntrAvailable, action, &QAction::setEnabled);
 
     ADD_ACTION_SHORTCUT_ICON("go_next_fuzzyUntr", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Next not ready"), Qt::CTRL + Qt::SHIFT + Qt::Key_PageDown, "nextfuzzyuntrans")
-    connect(action, &QAction::triggered, this, QOverload<>::of(&EditorTab::gotoNextFuzzyUntr));
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoNextFuzzyUntrRequested, this, QOverload<>::of(&EditorTab::gotoNextFuzzyUntr));
+    connect(action, &QAction::triggered, this, qOverload<>(&EditorTab::gotoNextFuzzyUntr));
+    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoNextFuzzyUntrRequested, this, qOverload<>(&EditorTab::gotoNextFuzzyUntr));
     connect(this, &EditorTab::signalNextFuzzyOrUntrAvailable, action, &QAction::setEnabled);
 
     action = nav->addAction(QStringLiteral("go_focus_earch_line"), m_transUnitsView, SLOT(setFocus()));
@@ -750,14 +735,12 @@ void EditorTab::hideDocks()
 
 void EditorTab::showDocks()
 {
-    return;
-    if (m_transUnitsView->isFloating())
-        m_transUnitsView->show();
 }
 
 void EditorTab::setProperCaption(QString title, bool modified)
 {
-    if (m_catalog->autoSaveRecovered()) title += ' ' + i18nc("editor tab name", "(recovered)");
+    if (m_catalog->autoSaveRecovered())
+        title += i18nc("editor tab title addition", " (recovered)");
     setWindowTitle(title + QStringLiteral(" [*]"));
     setWindowModified(modified);
 }
@@ -798,6 +781,25 @@ void EditorTab::updateCaptionPath()
 bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QString, QMdiSubWindow*> openedFiles, bool silent)
 {
     if (!m_catalog->isClean()) {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        switch (KMessageBox::warningTwoActionsCancel(
+                    SettingsController::instance()->mainWindowPtr(),
+                    i18nc("@info", "The document contains unsaved changes.\n"
+                          "Do you want to save your changes or discard them?"),
+                    i18nc("@title:window", "Warning"),
+                    KStandardGuiItem::save(),
+                    KStandardGuiItem::discard())) {
+        case KMessageBox::PrimaryAction:
+            if (!saveFile())
+                return false;
+            break;
+        case KMessageBox::SecondaryAction:
+            break;
+        case KMessageBox::Cancel:
+            return false;
+        default:;
+        }
+#else
         switch (KMessageBox::warningYesNoCancel(SettingsController::instance()->mainWindowPtr(),
                                                 i18nc("@info", "The document contains unsaved changes.\n"
                                                         "Do you want to save your changes or discard them?"), i18nc("@title:window", "Warning"),
@@ -807,6 +809,7 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QStrin
         case KMessageBox::Cancel:               return false;
         default:;
         }
+#endif
     }
     if (suggestedDirPath.isEmpty())
         suggestedDirPath = m_catalog->url();
@@ -825,7 +828,7 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QStrin
         //check if we are opening template
         QString newPath = filePath;
         newPath.replace(Project::instance()->poDir(), Project::instance()->potDir());
-        if (QFile::exists(newPath) || QFile::exists(newPath += 't')) {
+        if (QFile::exists(newPath) || QFile::exists(newPath += QLatin1Char('t'))) {
             saidPath = filePath;
             filePath = newPath;
         }
@@ -912,8 +915,8 @@ bool EditorTab::saveFileAs(const QString& defaultPath)
     QString filePath = QFileDialog::getSaveFileName(this, i18nc("@title:window", "Save File As"),
                        QFileInfo(defaultPath.isEmpty() ? m_catalog->url() : defaultPath).absoluteFilePath(), m_catalog->fileType());
     if (filePath.isEmpty()) return false;
-    if (!Catalog::extIsSupported(filePath) && m_catalog->url().contains('.'))
-        filePath += m_catalog->url().midRef(m_catalog->url().lastIndexOf('.'));
+    if (!Catalog::extIsSupported(filePath) && m_catalog->url().contains(QLatin1Char('.')))
+        filePath += m_catalog->url().midRef(m_catalog->url().lastIndexOf(QLatin1Char('.')));
 
     return saveFile(filePath);
 }
@@ -962,10 +965,26 @@ EditorState EditorTab::state()
 
 bool EditorTab::queryClose()
 {
-    bool clean = m_catalog->isClean() && !m_syncView->isModified() && !m_syncViewSecondary->isModified();
-    if (clean) return true;
+    const bool clean = m_catalog->isClean() && !m_syncView->isModified() && !m_syncViewSecondary->isModified();
+    if (clean)
+        return true;
 
-    //TODO caption
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    switch (KMessageBox::warningTwoActionsCancel(
+                this,
+                i18nc("@info", "The document contains unsaved changes.\n"
+                      "Do you want to save your changes or discard them?"),
+                i18nc("@title:window", "Warning"),
+                KStandardGuiItem::save(),
+                KStandardGuiItem::discard())) {
+    case KMessageBox::PrimaryAction:
+        return saveFile();
+    case KMessageBox::SecondaryAction:
+        return true;
+    default:
+        return false;
+    }
+#else
     switch (KMessageBox::warningYesNoCancel(this,
                                             i18nc("@info", "The document contains unsaved changes.\n"
                                                     "Do you want to save your changes or discard them?"), i18nc("@title:window", "Warning"),
@@ -974,6 +993,7 @@ bool EditorTab::queryClose()
     case KMessageBox::No:  return true;
     default:               return false;
     }
+#endif
 }
 
 
@@ -1367,7 +1387,7 @@ void EditorTab::launchPology()
         m_pologyProcess = new KProcess;
         m_pologyProcess->setOutputChannelMode(KProcess::SeparateChannels);
         qCWarning(LOKALIZE_LOG) << "Launching pology command: " << command;
-        connect(m_pologyProcess, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished),
+        connect(m_pologyProcess, qOverload<int, QProcess::ExitStatus>(&KProcess::finished),
                 this, &EditorTab::pologyHasFinished);
         m_pologyProcess->setShellCommand(command);
         m_pologyProcessInProgress = true;
@@ -1379,7 +1399,7 @@ void EditorTab::launchPology()
 
 void EditorTab::pologyHasFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    const QString pologyError = m_pologyProcess->readAllStandardError();
+    const QString pologyError = QString::fromLatin1(m_pologyProcess->readAllStandardError());
     if (exitStatus == QProcess::CrashExit) {
         KMessageBox::error(this, i18n("The Pology check has crashed unexpectedly:\n%1", pologyError), i18n("Pology error"));
     } else if (exitCode == 0) {
@@ -1393,17 +1413,28 @@ void EditorTab::pologyHasFinished(int exitCode, QProcess::ExitStatus exitStatus)
 
 void EditorTab::clearTranslatedEntries()
 {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    switch (KMessageBox::warningContinueCancel(
+                this,
+                i18nc("@info", "This will delete all the translations from the file.\n"
+                      "Do you really want to clear all translated entries?"),
+                i18nc("@title:window", "Warning"),
+                KStandardGuiItem::clear())) {
+    case KMessageBox::PrimaryAction: {
+#else
     switch (KMessageBox::warningYesNoCancel(this,
                                             i18nc("@info", "This will delete all the translations from the file.\n"
                                                     "Do you really want to clear all translated entries?"), i18nc("@title:window", "Warning"),
                                             KStandardGuiItem::yes(), KStandardGuiItem::no())) {
     case KMessageBox::Yes: {
+#endif
         DocPosition pos(0);
         do {
             removeTargetSubstring(m_catalog, pos);
         } while (switchNext(m_catalog, pos));
         msgStrChanged();
         gotoEntry(m_currentPos);
+        break;
     }
     default:;
     }
@@ -1414,7 +1445,7 @@ void EditorTab::displayWordCount()
     //TODO in trans and fuzzy separately
     int sourceCount = 0;
     int targetCount = 0;
-    QRegExp rxClean(Project::instance()->markup() + '|' + Project::instance()->accel()); //cleaning regexp; NOTE isEmpty()?
+    QRegExp rxClean(Project::instance()->markup() + QLatin1Char('|') + Project::instance()->accel()); //cleaning regexp; NOTE isEmpty()?
     QRegExp rxSplit(QStringLiteral("\\W|\\d"));//splitting regexp
     DocPosition pos(0);
     do {
@@ -1437,7 +1468,7 @@ bool EditorTab::findEntryBySourceContext(const QString& source, const QString& c
 {
     DocPosition pos(0);
     do {
-        if (m_catalog->source(pos) == source && m_catalog->context(pos.entry) == QStringList(ctxt)) {
+        if (m_catalog->source(pos) == source && m_catalog->context(DocPosition(pos.entry)) == QStringList(ctxt)) {
             gotoEntry(pos);
             return true;
         }
@@ -1522,34 +1553,46 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
 
     QString dir = Project::instance()->local()->sourceDir();
     if (dir.isEmpty()) {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        switch (KMessageBox::questionTwoActionsCancel(
+                    SettingsController::instance()->mainWindowPtr(),
+                    i18nc("@info", "Would you like to search for the source file locally or via lxr.kde.org?"),
+                    i18nc("@title", "Source file lookup"),
+                    KGuiItem(i18nc("@action", "Search Locally")),
+                    KGuiItem(i18nc("@action", "Search on lxr.kde.org")),
+                    KStandardGuiItem::cancel())) {
+        case KMessageBox::PrimaryAction:
+            dir = QFileDialog::getExistingDirectory(this, i18n("Select project's base folder for source file lookup"), QDir::homePath());
+            if (dir.length())
+                Project::instance()->local()->setSourceDir(dir);
+            break;
+        case KMessageBox::SecondaryAction:
+            openLxrSearch(srcFileRelPath);
+            return;
+#else
         switch (KMessageBox::questionYesNoCancel(SettingsController::instance()->mainWindowPtr(),
                 i18nc("@info", "Would you like to search for the source file locally or via lxr.kde.org?"), i18nc("@title:window", "Source file lookup"),
-                KGuiItem(i18n("Locally")), KGuiItem("lxr.kde.org")
+                KGuiItem(i18n("Locally")), KGuiItem(QStringLiteral("lxr.kde.org"))
                                                 )) {
         case KMessageBox::Yes: break;
         case KMessageBox::No: openLxrSearch(srcFileRelPath);
+#endif
         case KMessageBox::Cancel:
         default:
             return;
         }
     }
 
-    //hard fallback
-    if (dir.isEmpty()) {
-        dir = QFileDialog::getExistingDirectory(this, i18n("Select project's base folder for source file lookup"), QDir::homePath());
-        if (dir.length())
-            Project::instance()->local()->setSourceDir(dir);
-    }
     if (dir.length()) {
         auto doOpen = [srcFileRelPath, dir, line]() {
             auto sourceFilePaths = Project::instance()->sourceFilePaths();
-            QString absFilePath = QString("%1/%2").arg(dir, srcFileRelPath);
+            QString absFilePath = QStringLiteral("%1/%2").arg(dir, srcFileRelPath);
             if (QFileInfo::exists(absFilePath)) {
                 openLocalSource(absFilePath, line);
                 return;
             }
             bool found = false;
-            QByteArray fn = srcFileRelPath.midRef(srcFileRelPath.lastIndexOf('/') + 1).toUtf8();
+            QByteArray fn = srcFileRelPath.midRef(srcFileRelPath.lastIndexOf(QLatin1Char('/')) + 1).toUtf8();
             auto it = sourceFilePaths.constFind(fn);
             while (it != sourceFilePaths.constEnd() && it.key() == fn) {
                 const QString absFilePath = QString::fromUtf8(it.value() + '/' + fn);
@@ -1562,6 +1605,34 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
                 it++;
             }
             if (!found) {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                switch (KMessageBox::warningTwoActionsCancel(
+                            SettingsController::instance()->mainWindowPtr(),
+                            i18nc("@info", "Could not find source file in the folder specified.\n"
+                                  "Do you want to change source files folder?"),
+                            i18nc("@title:window", "Source file lookup"),
+                            KGuiItem(i18nc("@action", "Select Folder")),
+                            KGuiItem(i18nc("@action", "Search on lxr.kde.org")),
+                            KStandardGuiItem::cancel())) {
+                case KMessageBox::PrimaryAction: {
+                    QString dir = QFileDialog::getExistingDirectory(nullptr, i18n("Select project's base folder for source file lookup"), Project::instance()->local()->sourceDir());
+                    if (dir.length()) {
+                        Project::instance()->local()->setSourceDir(dir);
+                        Project::instance()->resetSourceFilePaths();
+                    }
+                    break;
+                }
+                case KMessageBox::SecondaryAction:
+                    Project::instance()->local()->setSourceDir(QString());
+                    Project::instance()->resetSourceFilePaths();
+                    openLxrSearch(srcFileRelPath);
+                    return;
+                case KMessageBox::Cancel:
+                    return;
+                default:
+                    break;
+                }
+#else
                 switch (KMessageBox::warningYesNoCancel(SettingsController::instance()->mainWindowPtr(),
                                                         i18nc("@info", "Could not find source file in the folder specified.\n"
                                                                 "Do you want to change source files folder?"), i18nc("@title:window", "Source file lookup"),
@@ -1572,15 +1643,15 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
                     openLxrSearch(srcFileRelPath);
                 case KMessageBox::No:
                     return;
-                default: ; //fall through to dir selection
+                default: {
+                    QString dir = QFileDialog::getExistingDirectory(nullptr, i18n("Select project's base folder for source file lookup"), Project::instance()->local()->sourceDir());
+                    if (dir.length()) {
+                        Project::instance()->local()->setSourceDir(dir);
+                        Project::instance()->resetSourceFilePaths();
+                    }
                 }
-
-                QString dir = QFileDialog::getExistingDirectory(nullptr, i18n("Select project's base folder for source file lookup"), Project::instance()->local()->sourceDir());
-                if (dir.length()) {
-                    Project::instance()->local()->setSourceDir(dir);
-                    Project::instance()->resetSourceFilePaths();
                 }
-
+#endif
             }
         };
         if (Project::instance()->isSourceFilePathsReady())
@@ -1645,7 +1716,7 @@ void EditorTab::mergeIntoOpenDocument()
     QString targetLangCode = m_catalog->targetLangCode();
 
     QStringList args(m_catalog->url());
-    args.append(xliffFolder + '/' + originalOdfFileInfo.baseName() + '-' + targetLangCode + '.' + originalOdfFileInfo.suffix());
+    args.append(xliffFolder + QLatin1Char('/') + originalOdfFileInfo.baseName() + QLatin1Char('-') + targetLangCode + QLatin1Char('.') + originalOdfFileInfo.suffix());
     args.append(QStringLiteral("-t"));
     args.append(originalOdfFilePath);
     qCDebug(LOKALIZE_LOG) << args;
@@ -1661,7 +1732,7 @@ void EditorTab::mergeIntoOpenDocument()
             return;
         }
 
-        if (QProcess::execute(lowriter, QStringList("--version")) == -2) {
+        if (QProcess::execute(lowriter, QStringList(QStringLiteral("--version"))) == -2) {
             //TODO
             //KMessageBox::error(SettingsController::instance()->mainWindowPtr(), i18n("Install translate-toolkit package and retry"));
             return;
@@ -1777,7 +1848,7 @@ QString EditorTab::targetLangCode()
 }
 void EditorTab::addEntryNote(int entry, const QString& note)
 {
-    m_notesView->addNote(entry, note);
+    m_notesView->addNote(DocPosition(entry), note);
 }
 void EditorTab::addTemporaryEntryNote(int entry, const QString& note)
 {
@@ -1808,3 +1879,5 @@ void EditorTab::setEntryTarget(int entry, int form, const QString& content)
         m_view->gotoEntry();
 }
 //END DBus interface
+
+#include "moc_editortab.cpp"
